import React, { useState, useEffect } from 'react';
import { Grid } from '@material-ui/core';
import { PhoneOutlined } from '@material-ui/icons';
import Link from 'next/link';
import { useSession, signIn, signOut } from "next-auth/react";
import { useSelector, useDispatch } from 'react-redux';
import { useRouter } from "next/router";
import { setCurrency, currencyChange, addItem, saveAllCountryData,saveFlagData,checkCartItemWithTimeLimit,setFirstTimeData } from '../../redux/actions/cart';
import Image from 'next/image';
import config from '../../config/config';
import EmailIcon from '@material-ui/icons/Email';
import SearchIcon from '@material-ui/icons/Search';
import dynamic from 'next/dynamic';
import LocalShippingIcon from '@material-ui/icons/LocalShipping';
import MoreVertIcon from '@material-ui/icons/MoreVert';
import styles from '../../components/Navbar/navbarstyle/navbar.module.css'
import ArrowDropDownIcon from '@material-ui/icons/ArrowDropDown';
import { ArrowDropDownOutlined } from '@material-ui/icons';
import {FlagsData} from '../Component/FlagsData';
import {SetFlag} from '../CommonFunctions/SetFlag';
import {GetCookieStorage} from '../../redux/lib/localstorage';

const AustraliaMenu = dynamic(() => import('./AustraliaNavbar'), {
   loading: () => <header />,
})

const UsaMenu = dynamic(() => import('./UsaNavbar'), {
  loading: () => <header />,
})

const CanadaMenu = dynamic(() => import('./CanadaNavbar'), {
  loading: () => <header />,
})

const UkMenu = dynamic(() => import('./UkNavbar'), {
  loading: () => <header />,
})

const UaeMenu = dynamic(() => import('./UaeNavbar'), {
  loading: () => <header />,
})

const GermanyMenu = dynamic(() => import('./GermanyNavbar'), {
  loading: () => <header />,
})

const SingaporeMenu = dynamic(() => import('./SingaporeNavbar'), {
  loading: () => <header />,
})

const IndiaMenu = dynamic(() => import('./IndiaNavbar'), {
  loading: () => <header />,
})
const USAMobNavbar = dynamic(() => import('./MobileMenu/USAMobNavbar.jsx'), {
  loading: () => <header />,
})


const AustraliaMobNavbar = dynamic(() => import('./MobileMenu/AustraliaMobNavbar.jsx'), {
  loading: () => <header />,
})

const CanadaMobNavbar = dynamic(() => import('./MobileMenu/CanadaMobNavbar.jsx'), {
  loading: () => <header />,
})

const UkMobNavbar = dynamic(() => import('./MobileMenu/UKMobNavbar.jsx'), {
  loading: () => <header />,
})

const UaeMobNavbar = dynamic(() => import('./MobileMenu/UAEMobNavbar.jsx'), {
  loading: () => <header />,
})

const GermanyMobNavbar = dynamic(() => import('./MobileMenu/GermanyMobNavbar.jsx'), {
  loading: () => <header />,
})

const SingaporeMobNavbar = dynamic(() => import('./MobileMenu/SingaporeMobNavbar.jsx'), {
  loading: () => <header />,
})

export default function Navbar(props) {
	const dispatch = useDispatch();
	const CartTotalItem = useSelector(state => state.cartReducer.TotalItems);
	const AllCurrency = useSelector(state => state.cartReducer.AllCountryData);
	const SelectedCurr = useSelector(state => state.cartReducer.CurrencyData);
	const FlagData = useSelector(state => state.cartReducer.FlagData);
	const router = useRouter()
	const saveAllCurr = (allCurrncy, Current_crr, geo_data) => dispatch(saveAllCountryData(allCurrncy, Current_crr, geo_data))
	const checkCartItemWithDateTimeLimit = () => dispatch(checkCartItemWithTimeLimit())	
	const [searchText, setsearchText] = useState('');
	const [SelectedFlag, setSelectedFlag] = useState(FlagData);
	const [countryID, setcountryID] = useState('');
	const [selectedItemIndex, setselectedItemIndex] = useState(null);
	const [itemsList, setitemsList] = useState(props.AllCurrencyData);
	const [DisplayCurrencyDropdown, setDisplayCurrencyDropdown] = useState(false);	
	const { data: session } = useSession();

	useEffect(() => {	
		if(itemsList.length > 0){
			if(!SelectedCurr){
				var currentCurrency = props.currentCurrency
				var AllCountryData = props.AllCurrencyData
				var GeoData = props.GeoData
				setcurrencydadtanew()
				async function setcurrencydadtanew(){
					await dispatch(setFirstTimeData(currentCurrency, AllCountryData, GeoData))
				}
				var nccode = currentCurrency.CountryCode
				itemsList.map(async (vals, inds) => {
					if (vals.CountryCode === nccode) {
						setselectedItemIndex(inds)
					}
				})
			}else{
				var nccode = SelectedCurr.CountryCode
				itemsList.map(async (vals, inds) => {
					if (vals.CountryCode === nccode) {
						setselectedItemIndex(inds)
					}
				})
			}
			setDisplayCurrencyDropdown(true)
		}
	}, [itemsList,SelectedCurr])
	
	useEffect(() => {	
		checkCartItemWithDateTimeLimit()
		
		if(props.countryId){
			if(props.countryId == '4'){
				SetFlag({"id":'4',"name":'USA',"url":'usa',"img":'/country-flag/usa.png'})
			}else if(props.countryId == '30'){
				SetFlag({"id":'30',"name":'UK',"url":'uk',"img":'/country-flag/uk.png'})
			}else if(props.countryId == '31'){
				SetFlag({"id":'31',"name":'UAE',"url":'uae',"img":'/country-flag/uae.png'})
			}else if(props.countryId == '5'){
				SetFlag({"id":'5',"name":'CANADA',"url":'canada',"img":'/country-flag/canada.png'})
			}else if(props.countryId == '32'){
				SetFlag({"id":'32',"name":'GERMANY',"url":'germany',"img":'/country-flag/germany.png'})
			}else if(props.countryId == '33'){
				SetFlag({"id":'33',"name":'SINGAPORE',"url":'singapore',"img":'/country-flag/singapore.jpg'})
			}else if(props.countryId == '3'){
				SetFlag({"id":'3',"name":'Australia',"url":'australia',"img":'/country-flag/australia.jpg'})
			}else{
				SetFlag({"id":'2',"name":'INDIA',"url":'',"img":'/country-flag/india.png'})
			}
			setcountryID(props.countryId)
		}else if(props.selectedCountryFlag){
			if(props.selectedCountryFlag == '4'){
				SetFlag({"id":'4',"name":'USA',"url":'usa',"img":'/country-flag/usa.png'})
			}else if(props.selectedCountryFlag == '30'){
				SetFlag({"id":'30',"name":'UK',"url":'uk',"img":'/country-flag/uk.png'})
			}else if(props.selectedCountryFlag == '31'){
				SetFlag({"id":'31',"name":'UAE',"url":'uae',"img":'/country-flag/uae.png'})
			}else if(props.selectedCountryFlag == '5'){
				SetFlag({"id":'5',"name":'CANADA',"url":'canada',"img":'/country-flag/canada.png'})
			}else if(props.selectedCountryFlag == '32'){
				SetFlag({"id":'32',"name":'GERMANY',"url":'germany',"img":'/country-flag/germany.png'})
			}else if(props.selectedCountryFlag == '33'){
				SetFlag({"id":'33',"name":'SINGAPORE',"url":'singapore',"img":'/country-flag/singapore.jpg'})
			}else if(props.selectedCountryFlag == '3'){
				SetFlag({"id":'3',"name":'Australia',"url":'australia',"img":'/country-flag/australia.jpg'})
			}else{
				SetFlag({"id":'2',"name":'INDIA',"url":'',"img":'/country-flag/india.png'})
			}
			setcountryID(props.selectedCountryFlag)
		}
		else{
			SetFlag({"id":'2',"name":'INDIA',"url":'',"img":'/country-flag/india.png'})
			setcountryID(2)
		}		
	}, [props.countryId])

	useEffect(() => {	
	
	}, [FlagData])

	function handleClick(e) {
		e.preventDefault();
		var values = searchText.replace(/^[ \t]+|[ \t]+$/gm, "");
		router.push(`/search?stext=${values}&cid=${countryID}`, null, { shallow: true });
	};

	async function changeCurrency(item, index) {
		item.index = index
		dispatch(currencyChange(item))
		window.location.reload(false);
	}

	function getsearchText(e) {		
		var searchtextv = e.target.value;		
		setsearchText(searchtextv)
	}	
	
	return (
		<>
			{/* Mobile-navbar-start */}
			<div className={styles.mobile_main_container}>
				<div className={styles.mobile_header}>
					<div className={styles.phn_logo}>
						<div className={styles.Logo}>
							<Link href={config.callBackUrl} ><a>
								<Image width="153" height="55" src={`${config.callBackUrl}e-gifts-white-logo.png`} />
							</a></Link>
						</div>
					</div>
					<div className={styles.right_phn_icon}>
						<span className={styles.pcart}>
							<Link prefetch={false} href={`${config.callBackUrl}cart`}><a><Image width="30" height="30" src='/cart-white.png' className='imgbansmall' alt="" />
								<div className={styles.cartcount}>{CartTotalItem}</div>
							</a></Link>
						</span>
						<div className={styles.mobile_topright_corner}>
							<MoreVertIcon className={styles.MoreVertIcon} width="2%"  />
							<div className={styles.mobileNav}>
								<input type="checkbox" className="top_nav" id="menu-11" />
								<div id="menu-cont-1">
									<label className="m_menu_label" htmlFor="menu-11">Back</label>
									<ul className="m_menu_ul">
										<li className="nav_item"><Link prefetch={false} href={`${config.callBackUrl}auth/dashboard`}><a>My Account</a></Link></li>
										<li className="nav_item"><Link prefetch={false} href={`${config.callBackUrl}track-order`}><a>Track Order</a></Link></li>
										<li className="nav_item"><Link prefetch={false}  href={`${config.callBackUrl}become-a-partner`}><a>Partner with us</a></Link></li>
										<li className="nav_item"><Link prefetch={false} href={`${config.callBackUrl}offers`}><a>Offers</a></Link></li>
										{(itemsList.length > 0) ?
											<>
												<li className="nav_item m-sub-menu">Currency
													<input type="checkbox" id="menu-1" />
													<div id="menu-cont-2">
														<ul className="m_menu_ul">
															<label className="m_menu_label" htmlFor="menu-1">Back</label>

															{itemsList.map((item, index) => (
																<li className="nav_item" key={index}>
																	<div className={styles.dropdown_item} onClick={e => { changeCurrency(item, index); }}>
																		{item.CurrencyName}
																		<span> {item.CurrencySymbol}</span>
																	</div>
																</li>
															)
															)}
														</ul>
													</div>
												</li>
											</>
											:
											<>
											</>
										}
									</ul>
								</div>
							</div>
						</div>
					</div>
				</div>
				<div className={styles.phn_search_sec}>
					<div className={styles.mobile_menu_sec}>
						<div className={styles.nav_container}>
							<div className={styles.bg}></div>
							<div className={styles.icon_button} tabIndex='0'>
								<span className={styles.icon_bar}></span>
								<span className={styles.icon_bar}></span>
								<span className={styles.icon_bar}></span>
							</div>
							<div className={styles.nav_content} tabIndex='0' >
								<div className={styles.mobile_menu_header}>
									<div className={styles.mobile_menu_nav}>
										{(session) ?
											<div className={styles.mobile_menu_nav_inner}>
												<div className={styles.mobile_profile}>
													<Image width="26" height="26" src='/user-white.webp' className='imgbansmall' alt="" />
													<p>Hi {session.user.name}</p>
													{/* <button className={styles.closemenu} onClick={() => closemenu()} ><Clear className={styles.menucls}/></button> */}
												</div>
												<div className={styles.mobile_profile_btm}>
													<ul>
														<li><Link href='#' ><a>
															<button className={styles.sign_in_btnfrnt_mob} onClick={() => signOut()} >Sign Out</button>
														</a></Link>
														</li>
														<li> <Link prefetch={false} href={`${config.callBackUrl}track-order`}><a>Track Order</a></Link></li>
														<li><Link  prefetch={false} href={`${config.callBackUrl}contact`}><a>Help Center</a></Link></li>
													</ul>
												</div>
											</div>
											:
											<div className={styles.mobile_menu_nav_inner}>
												<div className={styles.mobile_profile}>
													<Image width="26" height="26" src='/user-white.webp' className='imgbansmall' alt="" />
													<p>Hi Guest</p>
													{/* <button className={styles.closemenu} ><Clear className={styles.menucls}/></button> */}
												</div>
												<div className={styles.mobile_profile_btm}>
													<ul>
														<li><Link href='#' ><a>
															<button className={styles.sign_in_btnfrnt_mob} onClick={() => signIn()} >{'Sign in'}</button>
														</a></Link>
														</li>
														<li> <Link prefetch={false} href={`${config.callBackUrl}track-order`}><a>Track Order</a></Link></li>
														<li><Link  prefetch={false} href={`${config.callBackUrl}contact`}><a>Help Center</a></Link></li>
													</ul>
												</div>
											</div>
										}
										<div>
											{
												(() => {
													if (countryID == '3') {
														return (
															<>
																<AustraliaMobNavbar />
															</>
														)
													} else if (countryID == '4') {

														return (
															<>
																<USAMobNavbar />
															</>
														)
													} else if (countryID == '5') {
														return (
															<>
																<CanadaMobNavbar />
															</>
														)
													} else if (countryID == '30') {
														return (
															<>
																<UkMobNavbar />
															</>
														)
													} else if (countryID == '31') {
														return (
															<>
																<UaeMobNavbar />
															</>
														)
													} else if (countryID == '32') {
														return (
															<>
																<GermanyMobNavbar />
															</>
														)
													}
													else if (countryID == '33') {
														return (
															<>
																<SingaporeMobNavbar />
															</>
														)
													} else {
														return (
															<>
																<ul className={styles.mobile_nav_list}>
																	<li>
																		<input id="group-1" type="checkbox" hidden />
																		<label htmlFor="group-1">Rakhi<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																		<ul className={styles.group_list}>
																			<li>
																				<input id="sub-group-1" type="checkbox" hidden />
																				<label htmlFor="sub-group-1">Rakhi By Recipient<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}bhaiya-bhabhi-rakhi`}><a>Bhaiya Bhabhi Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-for-brother`}><a>Brother Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-for-kids`}><a>Kids Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-return-gifts`}><a>Return Gift For Sister</a></Link></li>
																				</ul>

																				<input id="sub-group-01" type="checkbox" hidden />
																				<label htmlFor="sub-group-01">Rakhi By Sets<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi`}><a>Single Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}set-of-2-rakhi`}><a>Set of 2 Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}set-of-3-rakhi`}><a>Set of 3 Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}set-of-5-rakhi`}><a>Set of 4 Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}set-of-5-rakhi`}><a>Set of 5 Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}family-rakhi-combo`}><a>Family Rakhi set</a></Link></li>
																				</ul>

																				<input id="sub-group-02" type="checkbox" hidden />
																				<label htmlFor="sub-group-02">Rakhi By Combos<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-with-sweets`}><a>Rakhi with sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-with-chocolates`}><a>Rakhi with chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-with-dry-fruits`}><a>Rakhi with Dry Fruits</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi`}><a>Rakhi with Pooja thali</a></Link></li>
																				</ul>

																				<input id="sub-group-03" type="checkbox" hidden />
																				<label htmlFor="sub-group-03">International Rakhi Delivery<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-to-usa`}><a>Rakhi to USA</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-to-australia`}><a>Rakhi to Australia</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-to-canada`}><a>Rakhi to Canada</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi-to-germany`}><a>Rakhi to Germany</a></Link></li>
																				</ul>
																			</li>
																		</ul>
																	</li>
																	<li>
																		<input id="group-2" type="checkbox" hidden />
																		<label htmlFor="group-2">cakes <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																		<ul className={styles.group_list}>
																			<li>
																				<input id="sub-group-2" type="checkbox" hidden />
																				<label htmlFor="sub-group-2">By flavour <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}chocolate-cakes`}><a>Chocolate Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}vanilla-cakes`}><a>Vanilla Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}red-velvet-cakes`}><a>Red Velvet Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}black-forest-cakes`}><a>Black Forest Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}truffle-cakes`}><a>Truffle Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}fruit-cakes`}><a>Fruit Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}butterscotch-cakes`}><a>Butterscotch Cake</a></Link></li>
																				</ul>
																				<input id="sub-group-21" type="checkbox" hidden />
																				<label htmlFor="sub-group-21">By Occasion <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}birthday-cakes`}><a>Birthday Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}anniversary-cakes`}><a>Anniversary Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}1st-birthday-cakes`}><a>1st Birthday Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}1st-anniversary-cakes`}><a>1st Anniversary Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}25th-anniversary-cakes`}><a>25th Anniversary Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}wedding-cakes`}><a>Wedding Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes`}><a>All Cakes</a></Link></li>
																				</ul>
																			</li>
																		</ul>
																	</li>
																	<li>
																		<input id="group-3" type="checkbox" hidden />
																		<label htmlFor="group-3">Flowers <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																		<ul className={styles.group_list}>
																			<li>
																				<input id="sub-group-3" type="checkbox" hidden />
																				<label htmlFor="sub-group-3">By Type <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}roses`}><a>Roses</a></Link></li>
																					<li><Link href={`${config.callBackUrl}gerberas`}><a>Gerberas</a></Link></li>
																					<li><Link href={`${config.callBackUrl}lilies`}><a>Lilies</a></Link></li>
																					<li><Link href={`${config.callBackUrl}orchids`}><a>Orchids</a></Link></li>
																					<li><Link href={`${config.callBackUrl}carnations`}><a>Carnations</a></Link></li>
																					<li><Link href={`${config.callBackUrl}mixed-flowers`}><a>Mixed</a></Link></li>
																				</ul>
																				<input id="sub-group-31" type="checkbox" hidden />
																				<label htmlFor="sub-group-31">By Occasion <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}birthday-flowers`}><a>Birthday</a></Link></li>
																					<li><Link href={`${config.callBackUrl}anniversary-flowers`}><a>Anniversary</a></Link></li>
																					<li><Link href={`${config.callBackUrl}congratulations-flowers`}><a>congratulation</a></Link></li>
																					<li><Link href={`${config.callBackUrl}love-n-romance-flowers`}><a>Love & Romance Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}thank-you-flowers`}><a>thank You</a></Link></li>
																					<li><Link href={`${config.callBackUrl}i-am-sorry-flowers`}><a>I am Sorry Flowers</a></Link></li>
																				</ul>
																			</li>
																		</ul>
																	</li>
																	<li>
																		<input id="group-4" type="checkbox" hidden />
																		<label htmlFor="group-4">Occasions <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																		<ul className={styles.group_list}>
																			<li>
																				<input id="sub-group-4" type="checkbox" hidden />
																				<label htmlFor="sub-group-4">By Festivals <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																				    <li><Link href={`${config.callBackUrl}holi`}><a>Holi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}rakhi`}><a>Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}diwali`}><a>Diwali</a></Link></li>
																					<li><Link href={`${config.callBackUrl}ganesh-chaturthi`}><a>Ganesh Chaturthi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}christmas`}><a>Christmas</a></Link></li>
																					<li><Link href={`${config.callBackUrl}bhai-dooj`}><a>Bhai Dooj</a></Link></li>
																				</ul>
																				<input id="sub-group-41" type="checkbox" hidden />
																				<label htmlFor="sub-group-41">Everyday <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}birthday-cakes`}><a>Birthday Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}anniversary-cakes`}><a>Anniversary Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}1st-birthday-cakes`}><a>1st Birthday Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}1st-anniversary-cakes`}><a>1st Anniversary Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}25th-anniversary-cakes`}><a>25th Anniversary Cake</a></Link></li>
																					<li><Link href={`${config.callBackUrl}wedding-cakes`}><a>Wedding Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes`}><a>All Cakes</a></Link></li>
																				</ul>
																			</li>
																		</ul>
																	</li>
																	<li><Link href={`${config.callBackUrl}birthday-gifts`}><a>Birthday</a></Link></li>
																	<li><Link href={`${config.callBackUrl}anniversary-gifts`}><a>Anniversary</a></Link></li>
																	<li><Link href={`${config.callBackUrl}chocolates`}><a>chocolates</a></Link></li>
																	<li><Link href={`${config.callBackUrl}personalized-gifts`}><a>Personalized Gifts</a></Link></li>
																	<li>
																		<input id="group-5" type="checkbox" hidden />
																		<label htmlFor="group-5">Global <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																		<ul className={styles.group_list}>
																			<li>
																				<input id="sub-group-5" type="checkbox" hidden />
																				<label htmlFor="sub-group-5">USA <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-to-usa`}><a>Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}christmas-gifts-usa`}><a>Christmas</a></Link></li>
																					<li><Link href={`${config.callBackUrl}flowers-to-usa`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}usa`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-usa`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-usa`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-usa`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-usa`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}usa/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-usa`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-51" type="checkbox" hidden />
																				<label htmlFor="sub-group-51">UK <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}flowers-to-uk`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}uk`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-uk`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-uk`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-uk`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-uk`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}uk/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-uk`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-52" type="checkbox" hidden />
																				<label htmlFor="sub-group-52">UAE <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}flowers-to-uae`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}uae`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-uae`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-uae`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-uae`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-uae`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}uae/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-uae`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-53" type="checkbox" hidden />
																				<label htmlFor="sub-group-53">Canada <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-to-canada`}><a>Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}flowers-to-canada`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}canada`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-canada`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-canada`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-canada`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-canada`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}canada/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-canada`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-54" type="checkbox" hidden />
																				<label htmlFor="sub-group-54">Germany <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-to-germany`}><a>Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}flowers-to-germany`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}germany`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-germany`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-germany`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-germany`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-germany`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}germany/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-germany`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-55" type="checkbox" hidden />
																				<label htmlFor="sub-group-55">Australia<ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}rakhi-to-australia`}><a>Rakhi</a></Link></li>
																					<li><Link href={`${config.callBackUrl}diwali-gifts-australia`}><a>Diwali</a></Link></li>
																					<li><Link href={`${config.callBackUrl}flowers-to-australia`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}australia`}><a>Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}plants-to-australia`}><a>Plants</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-australia`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}chocolates-to-australia`}><a>chocolates</a></Link></li>
																					<li><Link href={`${config.callBackUrl}sweets-to-australia`}><a>Sweets</a></Link></li>
																					<li><Link href={`${config.callBackUrl}australia/sameday-gifts`}><a>Sameday Gifts</a></Link></li>
																					<li><Link href={`${config.callBackUrl}personalized-gifts-australia`}><a>Personalized Gifts</a></Link></li>
																				</ul>
																				<input id="sub-group-56" type="checkbox" hidden />
																				<label htmlFor="sub-group-56">Singapore <ArrowDropDownIcon width='10' className={styles.arrow_drop} /></label>
																				<ul className={styles.sub_group_list}>
																					<li><Link href={`${config.callBackUrl}flowers-to-singapore`}><a>Flowers</a></Link></li>
																					<li><Link href={`${config.callBackUrl}cakes-to-singapore`}><a>Cakes</a></Link></li>
																					<li><Link href={`${config.callBackUrl}singapore`}><a>Gifts</a></Link></li>
																					
																				</ul>
																			</li>
																		</ul>
																	</li>
																</ul>
															</>
														)
													}
												})()
											}
										</div>

									</div>
								</div>
							</div>
						</div>
					</div>
					<div className={styles.top_phn_search}>
						<div className={styles.phn_searchtopa}>
							<form name="search" id="searching" className={styles.psearching} method="post" action="">
								<input className={styles.pSearch} type="text" size="60" placeholder="Search for Gifts" name="search" onChange={(e) => getsearchText(e)} value={searchText} />
								<div className={styles.topsearch_btn}>
									<button className={styles.top_psearch_btn2} onClick={(e) => handleClick(e)} ><SearchIcon width="22" className={styles.p_top_searching_icon} /></button>
								</div>
							</form>
						</div>
					</div>
					<div className='mobile_contry_flags'>
						<div className={styles.menu_wrapper} >
						<div tabIndex="0" className="cntrymenu">
							<div className='sgift'>
										

										{(() => {
											if (countryID == '3') {
												return (
													<>
														<Image alt="" src={'/country-flag/australia.svg'} width="20" height="14"/>{'Australia'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '4') {

												return (
													<>
														<Image alt="" src={'/country-flag/usa.svg'} width="20" height="14"/>{'USA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '5') {
												return (
													<>
														<Image alt="" src={'/country-flag/canada.svg'} width="20" height="14"/>{'CANADA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '30') {
												return (
													<>
														<Image alt="" src={'/country-flag/uk.svg'} width="20" height="14"/>{'UK'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '31') {
												return (
													<>
														<Image alt="" src={'/country-flag/uae.svg'} width="20" height="14"/>{'UAE'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '32') {
												return (
													<>
														<Image alt="" src={'/country-flag/germany.svg'} width="20" height="14"/>{'GERMANY'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											}
											else if (countryID == '33') {
												return (
													<>
														<Image alt="" src={'/country-flag/singapore.svg'} width="20" height="14"/>{'SINGAPORE'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else {
												return (
													<>
														<Image alt="" src={'/country-flag/india.svg'} width="20" height="14"/>{'INDIA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											}
										})() }
										
										</div>
							<div className="contry_mobile_menu-dropdown">
							<ul>
								{FlagsData.map((item, index) => {

									var rdurl = config.callBackUrl+''+item.url
									var imgurl = '/country-flag/india.png';
									if(item.img){
										imgurl = item.img;
									}
									return(
										(countryID != item.id) ? 
											<li key = {index} onClick={e => { (SetFlag(item)) }}><Link href={`${rdurl}`}><a><Image alt="" src={imgurl} width="30" height="18" />{item.name}</a></Link></li>	
											:
											''
												
									)	
								}) }
							 </ul>
							  
							</div>
						  </div>
						</div>
					</div>
				</div>
			</div>


			<div className={`${styles.MainHeader} ${styles.head}`}>
				<div className={`${styles.Top_header} Top_header`} >
					<div className={styles.tp_wrapper}>
						<div className={`${styles.top_headerleftt} top_headerleftt topheadinner`} >
							<li><PhoneOutlined width="20" className={`${styles.Topicon} navtext Topicon`} />+91 - 8800491303</li>
							<li className='top_heading_lftli'><EmailIcon width="20" className={`${styles.Topicon} navtext Topicon`} />support@1800rakhis.com</li>
						</div>
						<div className='top_headerrgt'>
							<ul className={`${styles.topheadinner} topheadinner`}>
								<li><Link prefetch={false} href={`${config.callBackUrl}offers`}><a>Offers</a></Link></li>
								<li><Link prefetch={false} href={`${config.callBackUrl}become-a-partner`}><a>Partner with us</a></Link></li>
								{(itemsList.length > 0) ?
									<>
										<li className={`${styles.Curr_in} navtext navtext`}>Currency:
											<div className={`${styles.custom_dropdown} top_header_contry_select`}>
												<div className={styles.custom_dropdown_selection} >
													{selectedItemIndex != null ? itemsList[selectedItemIndex].name : 'select'}
												</div>
												<div className={styles.item_holder}>
													{itemsList.map((item, index) => (
														<div key={index} className={styles.dropdown_item} onClick={e => { changeCurrency(item, index); }}>
															{item.CurrencyName}
															<span> {item.CurrencySymbol}</span>
														</div>
													)
													)}
												</div>
											</div>
										</li>
									</>
									:
									<>
									</>
								}
								<li><LocalShippingIcon width="20" className={`${styles.Topicon} Topicon`} /><Link prefetch={false} href={`${config.callBackUrl}track-order`}><a>Track Order</a></Link></li>
							</ul>
						</div>
					</div>
				</div>
				<div className={`${styles.menu_header} ${styles.admin_header_bg}`}>
					<Grid className={styles.container_cmn}>
						<div className={styles.menuwrapper}>
							<div className={styles.lft_wrap}>
								<div className={styles.Logo}>
									<Link href={config.callBackUrl}><a><Image width="153" height="55" src={`${config.callBackUrl}logo.png`} alt = "1800rakhis"/></a></Link>
								</div>
							</div>
							<div className={styles.top_search}>
								<div className={styles.searchtopa}>
									<form name="search" id="searching" className={styles.searching} method="post" action="">
										<input className={styles.gSearch} type="search" size="60" placeholder="Search for Gifts" name="search" onChange={(e) => getsearchText(e)} value={searchText} />
										<div className={styles.topsearch_btn}>
											<button className={styles.top_search_btn2} onClick={(e) => handleClick(e)} ><SearchIcon width="22" className={styles.top_searching_icon} /></button>
										</div>
									</form>
								</div>
							</div>
							<div className={styles.right_menu_top}>
								<div className={styles.right_menu_wrap}>
									<span className={styles.needtoday}>
										<Link prefetch={false} href={`${config.callBackUrl}express-delivery`}><a><Image width="30" height="30" src='/3-hours.png' className='imgbansmall' alt="" />
											<p>Express Delivery</p></a></Link>
									</span>
									<span className={styles.loaction_ico}>
										<Link prefetch={false} href={`${config.callBackUrl}cart`}>
											<a><Image width="30" height="30" src='/cart.png' className='imgbansmall' alt="" />
												<div className={styles.cartcount}>{CartTotalItem}</div><p>Cart</p>
											</a></Link>
									</span>
									<span className={styles.serch_icon}>
										<Link prefetch={false} href={`${config.callBackUrl}contact`}>
											<a>
												<Image width="30" height="30" src='/help.png' className='help-icon' alt="" /><p>Help</p>
											</a>
										</Link>
									</span>
									<div className={styles.myprofilewrap}>
										<Image width="30" height="30" src='/accounts.png' className={styles.profileicomenu} alt="" />
										<div className={styles.profiledrp}>
											<ul>
												<li>
													{(session) ?
														<>
															<div className={styles.signouttext}>
																<p>{session.user.name}</p>
															</div>
															<ul className={styles.dropdown_glogin}>
																<li className={styles.insideli}>
																	<div className={styles.loginside}>
																		<Image width="26" height="26" src='/user-white.webp' className={styles.userloginico} alt="" />
																		<p>{session.user.name}</p>
																		<button className={styles.sign_up_btnfrnt} onClick={() => signOut()}>Sign out</button>
																	</div>
																</li>
																<div className={styles.login_account}> 
																	<ul>
																		<Link href={`${config.callBackUrl}auth/dashboard`}><a><li>My Accounts</li></a></Link>
																		<Link href={`${config.callBackUrl}auth/orders`}><a><li>My Orders</li></a></Link>
																	</ul>
															</div>
															</ul>
														</>
														:
														<>
															<div className={styles.woutlogin}>
																<p> Hi <span>Guest</span></p>
															</div>
															<ul>
																<li className={styles.insideli}>
																	<div className={styles.loginside}>
																		<Image width="26" height="26" src='/user-white.webp' className={styles.userloginico} alt="" />
																		<p>Hi <span>Guest</span></p>
																		<a>
																			<button className={styles.sign_in_btnfrnt} onClick={() => signIn()} >{'Sign in'}</button>
																		</a>
																	</div>
																</li>
                                                               
															</ul>
														</>
													}
												</li>
											</ul>
										</div>
									</div>
								</div>
							</div>
						</div>
					</Grid>
				</div>
				<div className={`${styles.menu_header} ${styles.main_menu}`}>
					<Grid className={styles.container_cmn}>
						<div className={styles.menuwrapper}>
							<div className={styles.nav_header}>
								<div className={styles.menu_wrapper} >
									{
										(() => {
											if (countryID == '3') {
												return (
													<>
														<AustraliaMenu />
													</>
												)
											} else if (countryID == '4') {

												return (
													<>
														<UsaMenu />
													</>
												)
											} else if (countryID == '5') {
												return (
													<>
														<CanadaMenu />
													</>
												)
											} else if (countryID == '30') {
												return (
													<>
														<UkMenu />
													</>
												)
											} else if (countryID == '31') {
												return (
													<>
														<UaeMenu />
													</>
												)
											} else if (countryID == '32') {
												return (
													<>
														<GermanyMenu />
													</>
												)
											}
											else if (countryID == '33') {
												return (
													<>
														<SingaporeMenu />
													</>
												)
											} else {
												return (
													<>
														<IndiaMenu />
													</>
												)
											}
										})()
									}

									<div tabIndex="0" className="cntrymenu">
										<div className='sgift'>
										<p>Send gifts to :</p>

										{(() => {
											if (countryID == '3') {
												return (
													<>
														<Image alt="" src={'/country-flag/australia.svg'} width="20" height="14"/>{'Australia'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '4') {

												return (
													<>
														<Image alt="" src={'/country-flag/usa.svg'} width="20" height="14"/>{'USA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '5') {
												return (
													<>
														<Image alt="" src={'/country-flag/canada.svg'} width="20" height="14"/>{'CANADA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '30') {
												return (
													<>
														<Image alt="" src={'/country-flag/uk.svg'} width="20" height="14"/>{'UK'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '31') {
												return (
													<>
														<Image alt="" src={'/country-flag/uae.svg'} width="20" height="14"/>{'UAE'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else if (countryID == '32') {
												return (
													<>
														<Image alt="" src={'/country-flag/germany.svg'} width="20" height="14"/>{'GERMANY'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											}
											else if (countryID == '33') {
												return (
													<>
														<Image alt="" src={'/country-flag/singapore.svg'} width="20" height="14"/>{'SINGAPORE'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											} else {
												return (
													<>
														<Image alt="" src={'/country-flag/india.svg'} width="20" height="14"/>{'INDIA'}
														<ArrowDropDownOutlined  width='10' className='downico country_arrow'/>
													</>
												)
											}
										})() }
										
										</div>
										<div className="contry_menu-dropdown">
											<ul>
											{FlagsData.map((item, index) => {

												var rdurl = config.callBackUrl+''+item.url
												var imgurl = '/country-flag/india.png';
												if(item.img){
													imgurl = item.img;
												}
												return(
													(countryID != item.id)  ? 
														<li key = {index} onClick={e => { (SetFlag(item)) }}><Link href={`${rdurl}`}><a><Image alt="" src={imgurl} width="30" height="18" />{item.name}</a></Link></li>	
															:
														''	
												)	
											}) }
											</ul>
										</div>
									</div>
								</div>
							</div>
						</div>
					</Grid>
				</div>
			</div>
			<div className={styles.hidden_div_for_fixed_header}></div>
		</>
	);
}
