import React, { useState, useEffect, AwesomeSlider } from 'react';
import Grid from '@material-ui/core/Grid';
import Navbar from '../components/Navbar/Navbar';
import Footer from '../components/Footer/Footer';
import Link from 'next/link';
import { PhoneOutlined, LocationOn } from '@material-ui/icons';
import MailOutlineIcon from '@material-ui/icons/MailOutline';
import config from "../config/config";
import Head from 'next/head';
import Breadcrumb from '../components/Component/Breadcrumbs';

export default function Contact({ currentCurrency, AllCurrencyData, GeoData, selectedCountryFlag }) {

	const [Name, setName] = useState('')
	const [Email, setEmail] = useState('')

	const [Phone, setPhone] = useState('')
	const [Comments, setComments] = useState('')

	const [NameErr, setNameErr] = useState(false)
	const [EmailErr, setEmailErr] = useState(false)
	const [PhoneErr, setPhoneErr] = useState(false)
	const [CommentsErr, setCommentsErr] = useState(false)

	const [successMsg, setsuccessMsg] = useState(false)
	const [errMsg, seterrMsg] = useState(false)
	const [isloading, setisloading] = useState(false)
	// const validDomains = ["gmail.com", "yahoo.com", "hotmail.com"];
	// const emailRegex = /^[A-Z0-9._+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i;

	function hidemessages() {
		setNameErr(false)
		setEmailErr(false)
		setPhoneErr(false)
		setCommentsErr(false)
	}

	// function validateEmail(email) {
	// 	const emailDomain = email.split("@")[1];
	// 	return emailRegex.test(email) && validDomains.includes(emailDomain);
	//   }
	function validateEmail(email) {
		var re = /^[A-Z0-9._+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i;
		return re.test(String(email).toLowerCase());
	  }

	function getName(e) {
		var n = e.target.value
		setName(n);
		hidemessages()
		setsuccessMsg(false)
		seterrMsg(false)
	}
	function getEmail(e) {
		var n = e.target.value
		setEmail(n);
		hidemessages()
		setsuccessMsg(false)
		seterrMsg(false)
	}
	function getPhone(e) {
		var n = e.target.value
		setPhone(n);
		hidemessages()
		setsuccessMsg(false)
		seterrMsg(false)
	}
	function getComments(e) {
		var n = e.target.value
		setComments(n);
		hidemessages()
		setsuccessMsg(false)
		seterrMsg(false)
	}
	async function sendMessage(e) {
		e.preventDefault()
		if (!Name) {
			setNameErr(true)
			return false;
		}
		else if (!Email) {
			setEmailErr('Email is required')
			return false;
		}
		else if (!validateEmail(Email)) {
			setEmailErr("Invalid email address");
			return false;
		}
		else if (!Phone) {
			setPhoneErr(true)
			return false;
		}
		else if (!Comments) {
			setCommentsErr(true)
			return false;
		} else {
			setisloading(true)
			var fetchurl = `${config.apiUrl}contact`;
			var uformData = {
				'name': Name,
				'email': Email,
				'Phone': Phone,
				'Comments': Comments,
			}
			const result = await fetch(fetchurl, {
				method: "POST",
				headers: {
				},
				body: JSON.stringify(uformData)
			});
			const response = await result.json();
			if (response.CODE == '200') {
				setisloading(false)
				setsuccessMsg(true)
				setName('')
				setEmail('')
				setPhone('')
				setComments('')
			} else {
				seterrMsg(true)
			}

		}
		setTimeout(function () {
			setsuccessMsg('')
			seterrMsg('')
		}, 3000);
	}

	return (
		<>

			<Head>

				<title>Contact - 1800rakhis</title>
				<link rel="canonical" href="https://1800rakhis.com/contact" />
			</Head>

			<Navbar countryId={''} currentCurrency={currentCurrency} AllCurrencyData={AllCurrencyData} GeoData={GeoData} selectedCountryFlag={selectedCountryFlag} />
			<Breadcrumb rootbreadcrumbtext='Contact' rootbreadcrumblink='' countryId='' breadcrumbtext='' selectedCountryFlag={selectedCountryFlag} />
			<Grid item md={12} sm={12} xs={12}>
				<Grid container className='contact-container form-section'>


					<div className="left-sections">
						<h1>Contact Details</h1>

						<div className='contact_detail_phn'>
							<div className='contact_detail_phn_inner'>
								<PhoneOutlined className='contact_icon' width='20' />
								<p>+91 8800491303</p>
							</div>
						</div>

						<div className='contact_detail_email'>
							<div className='contact_detail_email_inner'>
								<MailOutlineIcon className='contact_icon' width='20' />
								<Link href=''><a>support@1800rakhis.com</a></Link>
							</div>
						</div>

						<div className='contact_detail_email4'>
							<div className='contact_detail_email_inner'>
								<LocationOn className='contact_icon' width='20' />
								<p>EII ONLINE SERVICES PVT LTD , G14, FIRST FLOOR, SECTOR 3, NOIDA 201301</p>
							</div>
						</div>
					</div>




					<div className="right-sections">
						{isloading && (
							<span className='ew_loader_contact align-items-center justify-content-center d-flex w-100' >
								<img
									src='/loading.gif' className='loader_contact' alt="loader"
								/>
							</span>
						)}

						{(successMsg) ?
							<div className='contacterrdiv'>
								<p className='signin_error_con'>Thanks for contacting us!<br /> We will get back back to you soon!</p>
							</div>
							:
							<>
							</>
						}

						{(errMsg) ?
							<div className='contactsucdiv'>
								<p className='signin_error_con'>Form submissiion Failed!</p>
							</div>
							:
							<>
							</>
						}

						<form id="contact_form">
							<h1>Have Question?</h1>
							<div className="user-input-wrp">
								<br />
								<input type="text" className={'inputText ' + (NameErr ? 'inputsignuperr' : '')} required onChange={(e) => getName(e)} value={Name} />
								<div className='error_div_contact'>
									{(NameErr) ?
										<p className="errmsg_contact">Name is required</p>
										: ''
									}
								</div>
								<span className="floating-label">Name</span>
							</div>

							<div className="user-input-wrp">
								<br />
								<input type="text" className={'inputText ' + (EmailErr ? 'inputsignuperr' : '')} required onChange={(e) => getEmail(e)} value={Email}  />
								<div className='error_div_contact'>
									{(EmailErr) ?
										<p className="errmsg_contact">{EmailErr}</p>
										: ''
									}
									{EmailErr && <p className="errmsg_contact">{EmailErr}</p>}
								</div>
								<span className="floating-label">Email</span>
							</div>

							<div className="user-input-wrp">
								<br />
								<input type="text" className={'inputText ' + (PhoneErr ? 'inputsignuperr' : '')} required onChange={(e) => getPhone(e)} value={Phone} />
								<div className='error_div_contact'>
									{(PhoneErr) ?
										<p className="errmsg_contact">Phone No required</p>
										: ''
									}
								</div>
								<span className="floating-label">Phone</span>
							</div>

							<div className="user-input-wrp">
								<br />
								<textarea rows="1" className={'inputText ' + (CommentsErr ? 'inputsignuperr' : '')} required onChange={(e) => getComments(e)} value={Comments} />
								<div className='error_div_contact'>
									{(CommentsErr) ?
										<p className="errmsg_contact">Message is required</p>
										: ''
									}
								</div>
								<span className="floating-label">Message</span>
							</div>

							<button type="submit" className="contact_submit procartbtn" onClick={(e) => sendMessage(e)}><span>Submit</span></button>


						</form>
					</div>












				</Grid>
			</Grid>
			<Footer />

		</>

	)
}



export async function getServerSideProps(context) {
	var selectedCountryFlag = ''
	if (typeof (context.req.cookies.FlagData) !== 'undefined') {
		var selectedCountryFlagID = JSON.parse(context.req.cookies.FlagData)
		var selectedCountryFlag = selectedCountryFlagID.id
	} else {
		var selectedCountryFlag = '2';
	}
	if (typeof (context.req.cookies.CurrencyData) !== 'undefined') {
		var currentCurrency = JSON.parse(context.req.cookies.CurrencyData)
		var AllCountryData = JSON.parse(context.req.cookies.AllCountryData)
		var GeoData = JSON.parse(context.req.cookies.GeoData)
	} else {
		const forwarded = context.req.headers["x-forwarded-for"]
		const ip = forwarded ? forwarded.split(/, /)[0] : context.req.connection.remoteAddress
		const res = await fetch(`${config.apiUrl}setcurrency/?ip=${ip}`);

		var geoapiresponse = await res.json();

		var currentCurrency = geoapiresponse.current_currency
		var AllCountryData = geoapiresponse.all_currency
		var GeoData = geoapiresponse.GeoData
	}
	return {
		props: {
			currentCurrency: currentCurrency, AllCurrencyData: AllCountryData, GeoData: GeoData, selectedCountryFlag: selectedCountryFlag
		}
	}

}